#
# spec file for package sfml2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver -2_6
Name:           sfml2
Version:        2.6.1
Release:        2.5
Summary:        C++ multimedia library with access to input, sound and display
License:        Zlib
Group:          Development/Libraries/C and C++
URL:            https://www.sfml-dev.org/
Source0:        https://github.com/SFML/SFML/archive/%{version}/SFML-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisenc)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xrandr)
Requires:       lib%{name}%{so_ver} = %{version}

%description
SFML is a multimedia API that provides access to graphics, input,
audio, etc. similar to SDL.

%package -n lib%{name}%{so_ver}
Summary:        Free multimedia C++ API
Group:          System/Libraries

%description -n lib%{name}%{so_ver}
SFML is a multimedia API that provides access to graphics, input,
audio, etc., and may be seen as an object-oriented alternative to
SDL. It can be used as a minimal windowing system to interface with
OpenGL, or as a multimedia library for building games and interactive
programs.

%package devel
Summary:        SFML development files
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{so_ver} = %{version}
Requires:       pkgconfig(gl)
# Conflict with the sfml 1 devel package(same include files)
Conflicts:      sfml-devel

%description devel
SFML is a C++ multimedia API that provides a low and high-level
access to graphics, input, audio, etc., and may be seen as an
object-oriented alternative to SDL. SFML can be used as a minimal
windowing system to interface with OpenGL, or as a multimedia library
for building games or interactive programs.

This subpackage provides the header files needed to build SFML
programs.

%package doc
Summary:        SFML developer documentation
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
SFML is a multimedia API that provides access to graphics, input,
audio, etc. similar to SDL.

This subpackage contains the developer documentation.

%prep
%setup -q -n SFML-%{version}

%build
%cmake -DSFML_BUILD_DOC=TRUE \
       -DSFML_INSTALL_PKGCONFIG_FILES=TRUE \
       -DCMAKE_INSTALL_DOCDIR:PATH=%{_docdir}/SFML \
       -DCMAKE_BUILD_TYPE=RelWithDebInfo
%cmake_build

cd doc/html
%fdupes -s .

%install
%cmake_install

%post -n lib%{name}%{so_ver} -p /sbin/ldconfig
%postun -n lib%{name}%{so_ver} -p /sbin/ldconfig

%files -n lib%{name}%{so_ver}
%license license.md
%{_libdir}/libsfml-*.so.*

%files devel
%doc readme.md changelog.md
%{_includedir}/SFML
%{_libdir}/libsfml-*.so
%{_libdir}/pkgconfig/sfml-*.pc
%{_libdir}/cmake/SFML

%files doc
%doc %{_docdir}/SFML

%changelog
* Wed Feb 28 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Specify the documentation path so that it works across openSUSE versions.
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 2.6.1:
  General:
  * Stop overwriting CMAKE_MODULE_PATH (#2577)
  * Loosen restrictions on unknown compilers (#2585)
  * Fix unused compiler flag error in Clang (#2625)
  * Disable warnings as errors by default (#2680)
  Window:
  * Skip ClientMessage events with other window ID unless it is
    for IM (#2651)
  Graphics:
  * Ensure OpenGL extensions are loaded before querying maximum
    texture size (#2603)
  * Fix warnings in Linux OpenGL ES codepaths (#2747)
  * Remove use of C++11 header (#2591)
* Wed Jun 21 2023 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 2.6.0
  * Allow creation of a window without an OpenGL context
  * Add support for creating Vulkan window surfaces
  * Scancode support
  * Add support for colored cursors in Unix implementation
  * Add support for X Input Method
  * Add support for Direct Rendering Mode (DRM) / Kernel Mode Setting (KMS)
  * Added getPosition() and getSize() to sf::Rect
  * Implement smoothing for fonts
  * Add Min and Max blend modes
  * Update stb_image to 2.28, thus adding support for more image formats
  * Add MP3 decoding support
  * Added method to get the current read position of sf::Packet
  * Many bugfixes
* Fri Dec 14 2018 rpm@fthiessen.de
- Update to 2.5.1
- Changes in "Window"
  * Fixed dual monitor issue
  * Fixed issue where fullscreen window didn't go over task bars on
    top and left
  * Fixed the Unix clipboard implementation causing an abort due to
    internal data races in Xlib
- Changes in "Graphics"
  * Fixed a bug in which a sf::RenderTexture would not be
    re-activated after being re-created
  * Fixed sf::RenderTextureImplFBO's destructor incorrectly
    triggering deletion of other sf::RenderTextureImplFBO's active FBOs
  * Fix sf::RenderWindow::setActive incorrectly trying to unbind
    an FBO during deactivation
  * Fixed sf::RenderTexture::display() dereferencing a NULL pointer
    when being called before sf::RenderTexture::create()
  * Fixed bug in sf::Text when applying an outline color/thickness
  * Squash duplicated sf::Font glyphs to single chars
  * Fixed two issues with glyph sub-pixel positioning
  * Reduced context locking & unlocking while creating textures
  * Fixed the error message when the wrong bitmap font size is selected
- Changes in "Audio"
  * Fixed performance issue with reading WAV files
* Fri Dec 14 2018 rpm@fthiessen.de
- Update to 2.5.0
- Changes in "System"
  * Added protected destructor to sf::NonCopyable to prevent
    possible resource leaks
  * Fixed crash when sf::Clock is constructed in a global scope
- Changes in "Window"
  * Implemented Cursor API
  * Implemented Clipboard API
  * Renamed a few key codes
  * Added joystick example
  * Fixed sf::Window::getPosition() returning incorrect position
    because of differences in window managers
  * Fix X11 key repeat handling not filtering out events from other
    windows
  * Fix: Restore fullscreen of a non-visible window
- Changes in "Graphics"
  * Implemented additional line spacing and letter spacing in
    sf::Text
  * Added sf::VertexBuffer class
  * Added GPU local texture copying support, allowing performance
    optimizations and texture swapping
  * Optimize performance by skipping glTexCoordPointer() call if
    not needed
  * Generate shape outline vertices only if necessary
  * Removed dependency to libjpeg, stb_image_write now supports
    writing JPEG files
  * Enable comparing sf::Transform and optimize resetting OpenGL
    back to the identity matrix
  * Added missing setActive() virtual method to sf::RenderTarget
  * Updated stb_image to v2.16 and stb_image_write to v1.07,
    no need for dont-try-to-runtime-detect-sse2-on-gcc.diff
    anymore, fixed!
  * Added sf::RenderTexture stencil and multisampling support
  * Added example demonstrating sf::VertexBuffer, sf::Shader and
    sf::Thread usage
  * Optimized sf::RenderTexture performance
  * Properly free memory in sf::Font::cleanup()
  * Fixed memory leak in sf::Font
  * Fix OpenGL texture coordinate pointer not being updated correctly
    under certain conditions
  * Fix for broken text when the font is reloaded
  * Fix memory leak in sf::Text
  * Fixed strict aliasing punning warning when generating the key of
    a glyph in Font.cpp
  * Fixed OpenGL version string being parsed incorrectly on some platforms
- Changes in "Audio":
  * Added loop point support to sf::Music
  * Added support for the extensible PCM wave file format
  * Fixed inconsistent seek behavior in sf::SoundStream
  * Fixed stack overflow in sf::SoundStream::fillAndPushBuffer()
  * Fixed seeking quirks in the FLAC reader
  * Allow polymorphism with sf::SoundSource
  * Fixed WAV file writer writing wrong header values
  * Small bugfix to argument of alcCaptureOpenDevice()
- Changes in "Network"
  * Add append/overwrite parameter to Ftp::upload
  * Fixed wrong condition for building network support
  * Changed TCP listen backlog from 0 to SOMAXCONN
  * Fixed socket reuse not conforming to documentation
* Thu Jun 29 2017 mlin@suse.com
- Add dont-try-to-runtime-detect-sse2-on-gcc.diff from stb upstream
  * Give up trying to runtime-detect SSE2 on GCC, this fixes build
    failure in 42.3
* Sat Feb 18 2017 jengelh@inai.de
- RPM group fix.
* Wed Feb 15 2017 rpm@fthiessen.de
- Update to version 2.4.2
  * Fixed bug where TransientContextLock would hang
  * Fixed GLX extensions being loaded too late
  * Fix wrong types passed to XChangeProperty
  * Optimized sf::Image::create and made it more exception safe
- Dropped upstream merged fix-glx-extensions.patch
* Wed Jan 25 2017 rpm@fthiessen.de
- Added fix-glx-extensions.patch from upstream to fix missing
  multisampling.
* Sat Nov  5 2016 rpm@fthiessen.de
- Update to version 2.4.1
  * Fixed stack overflow on GlContext creation with multiple threads
  * Fixed fullscreen issue
  * Switched from XCB back to Xlib for windowing
  * Fixed window icon not showing up on some distros
  * Fixed an issue where GNOME flags window unresponsive
  * Fixed leak of XVisualInfo objects during GlxContext creation
  * Fixed possible hang when setting visibility if external
    window sources
* Thu Sep  1 2016 rpm@fthiessen.de
- Update to version 2.4.0
* Sun Jul 17 2016 jengelh@inai.de
- Update summary, trim description
- Enable ogg and vorbis dependencies explicitly
* Tue Sep 29 2015 rpm@fthiessen.de
- Fixed some problems in spec, found by factory-repo-checker:
  * Added baselibs.conf as source
  * Conflict with sfml-devel (sfml version 1.x devel package)
* Thu Sep 24 2015 rpm@fthiessen.de
- Updated to version 2.3.2:
  * Some bug fixes, see:
    http://www.sfml-dev.org/changelog.php#sfml-2.3.2
  * fix-upstream-no-return-in-nonvoid-function.patch got merged
    upstream, removed from spec / disabled.
* Sat Aug  1 2015 rpm@fthiessen.de
- Updated to version 2.3.1
  * Lot of bugfixes, see:
    http://www.sfml-dev.org/changelog.php#sfml-2.3.1
  * Added fix for RPMLint error caused by nonvoid functions
    without default return:
    fix-upstream-no-return-in-nonvoid-function.patch
* Thu Jul 30 2015 rpm@fthiessen.de
- Fixed wrong location in pkgconfig files
- SPEC cleanup
* Sat Feb 21 2015 rpm@fthiessen.de
- update to version 2.2 release
* Tue Sep 30 2014 mailaender@opensuse.org
- update to version 2.1 release
* Mon Sep  3 2012 adam@mizerski.pl
- updated to follow latest changes
- added _service for downloading sources from git
* Sun Aug 14 2011 adam@mizerski.pl
- removed bindings
- removed sfml2-2.0-better_image_smooth.patch
  (it was long before and undocumented)
* Fri Apr 22 2011 adam@mizerski.pl
- added sfml2-2.0-better_image_smooth.patch
* Thu Apr 14 2011 adam@mizerski.pl
- Changed source of sources from svn to git
* Sun Apr  3 2011 adam@mizerski.pl
- update to 2.0 r1816
* Tue Feb 22 2011 adam@mizerski.pl
- update to 2.0 r1800
* Sat Feb  5 2011 adam@mizerski.pl
- new package
